nameString with the name of the airport
ICAOString with the ICAO code of the airport
IATAString with the IATA code of the airport
longitudeLongitude of the position of the airport
latitudeLatitude of the position of the airport
altitudeAltitude of the position of the airport
cityString with the name of the city where the airport
is located
municipalityString with the ISO 3166-2 code where the
airport is located
regionString with the name of the region where the
airport is located
countryString with the ISO 3166-1 alpha-2 code of the country
where the airport is located
continentString with the ISO 3166-1 alpha-2 code of the
continent where the airport is located
typeString with information about the type of airport
websiteString with the URL for the website of the airport
wikipedia_entryString with the URL for the Wikipedia entry
of the airport
reliable_positionLogical value indicating if the position of
the airport is reliable
GPS_codeString with the GPS code of the airport