R6Class object representing a flight route, usually operated by
a commercial airline. Contains information about the callsign under which the
route is operated, the operator itself and the airports of origin and
destination. New instances can be manually created by providing values for at
least the fields call_sign, origin_airport and destination_airport.
Alternatively, getRouteMetadata will return an openSkiesRoute
object corresponding to the route with the provided callsign.